@@ -1,6 +1,6 @@
 package Linux::Epoll;
 {
-  $Linux::Epoll::VERSION = '0.004';
+  $Linux::Epoll::VERSION = '0.005';
 }
 
 use 5.010;
@@ -16,7 +16,7 @@ XSLoader::load(__PACKAGE__, __PACKAGE__->VERSION);
 #ABSTRACT: O(1) multiplexing for Linux
 
 
-
+__END__
 =pod
 
 =head1 NAME
@@ -25,14 +25,17 @@ Linux::Epoll - O(1) multiplexing for Linux
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
  use Linux::Epoll;
 
  my $epoll = Linux::Epoll->new();
- $epoll->add($fh, 'in', sub { do_something($fh) });
+ $epoll->add($fh, 'in', sub {
+     my $events = shift;
+     do_something($fh) if $events->{in};
+ });
  1 while $epoll->wait;
 
 =head1 DESCRIPTION
@@ -85,7 +88,7 @@ Create a new epoll instance.
 
 =head2 add($fh, $events, $callback)
 
-Register the filehandle with the epoll instance and associate events C<$events> and callback C<$callback> with it. C<$events> may be either a string (e.g. C<'in'>) or an arrayref (e.g. C<[qw/in out hup/]>). If a filehandle already exists in the set and C<add> is called in non-void context, it returns undef and sets C<$!> to C<EEXIST>. On all other error conditions an exception is thrown.
+Register the filehandle with the epoll instance and associate events C<$events> and callback C<$callback> with it. C<$events> may be either a string (e.g. C<'in'>) or an arrayref (e.g. C<[qw/in out hup/]>). If a filehandle already exists in the set and C<add> is called in non-void context, it returns undef and sets C<$!> to C<EEXIST>. On all other error conditions an exception is thrown. The callback gets a single argument, a hashref whose keys are the triggered events.
 
 =head2 modify($fh, $events, $callback)
 
@@ -97,7 +100,7 @@ Remove a filehandle from the epoll instance. If a filehandle doesn't exist in th
 
 =head2 wait($number = 1, $timeout = undef, $sigmask = undef)
 
-Wait for up to C<$number> events, where C<$number> must be greater than zero. C<$timeout> is the maximal time C<wait> will wait for events in fractional seconds. If it is undefined it may wait indefinitely. C<$sigmask> is the signal mask during the call. If it is not defined the signal mask will be untouched.
+Wait for up to C<$number> events, where C<$number> must be greater than zero. C<$timeout> is the maximal time C<wait> will wait for events in fractional seconds. If it is undefined it may wait indefinitely. C<$sigmask> is the signal mask during the call. If it is not defined the signal mask will be untouched. If interrupted by a signal and C<wait> is called in non-void context, it returns undef and sets C<$!> to C<EINTR>. On all other error conditions an exception is thrown.
 
 =head1 SEE ALSO
 
@@ -124,6 +127,3 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
-__END__
-
